Author: danielsh
Date: Tue Jan 9 08:16:18 2018
New Revision: 1820627
URL: http://svn.apache.org/viewvc?rev=1820627&view=rev
Log:
* subversion/tests/cmdline/davautocheck.sh:
Support a --lldb option alongside --gdb.
Modified:
subversion/trunk/subversion/tests/cmdline/davautocheck.sh
Modified: subversion/trunk/subversion/tests/cmdline/davautocheck.sh
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/davautocheck.sh?rev=1820627&r1=1820626&r2=1820627&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/cmdline/davautocheck.sh (original)
+++ subversion/trunk/subversion/tests/cmdline/davautocheck.sh Tue Jan 9
08:16:18 2018
@@ -79,8 +79,8 @@
# environment.
#
# Passing --no-tests as argv[1] will have the script start a server
# but not run any tests. Passing --gdb will do the same, and in addition
# spawn gdb in the foreground attached to the running server.
PYTHON=${PYTHON:-python}
@@ -763,6 +763,12 @@ if [ $# -eq 1 ] && [ "x$1" = 'x--no-test
exit
fi
+if [ $# -eq 1 ] && [ "x$1" = 'x--lldb' ]; then
+ echo "http://localhost:$HTTPD_PORT/svn-test-work/repositories"
+ $STOPSCRIPT && lldb --one-line=run -- $START -X
+ exit
+fi
+
if [ $# -eq 1 ] && [ "x$1" = 'x--gdb' ]; then
echo "http://localhost:$HTTPD_PORT/svn-test-work/repositories"
$STOPSCRIPT && gdb -silent -ex r -args $START -X
@@ -79,8 +79,8 @@
#
# Passing --no-tests as argv[1] will have the script start a server
-# but not run any tests. Passing --gdb will do the same, and in addition
-# spawn gdb in the foreground attached to the running server.
+# but not run any tests. Passing --gdb or --lldb will do the same, and in
+# addition spawn gdb/lldb in the foreground attached to the running server.
PYTHON=${PYTHON:-python}